@@ -5,10 +5,16 @@ use Fennec;
 use Fennec::Declare;
 
 tests simple {
+    ok( $self, "Magically got self" );
+    $self->isa_ok( 'TEST::Fennec::Declare' );
+    $self->isa_ok( 'Fennec::TestFile' );
     ok( 1, "In declared tests!" );
 }
 
 tests 'complicated name' {
+    ok( $self, "Magically got self" );
+    $self->isa_ok( 'TEST::Fennec::Declare' );
+    $self->isa_ok( 'Fennec::TestFile' );
     ok( 1, "Complicated name!" );
 }
 
@@ -21,22 +27,36 @@ tests old_deep => (
 );
 
 tests add_specs ( todo => 'not really todo' ) {
+    ok( $self, "Magically got self" );
+    $self->isa_ok( 'TEST::Fennec::Declare' );
+    $self->isa_ok( 'Fennec::TestFile' );
     TODO {
         ok( 0, "This should be todo" );
     } "Todo from Fennec bug #58";
 }
 
 cases some_cases {
+    ok( $self, "Magically got self" );
+    $self->isa_ok( 'TEST::Fennec::Declare' );
+    $self->isa_ok( 'Fennec::TestFile' );
+
     my $x = 0;
     case case_a { $x = 10 }
     case case_b { $x = 100 }
-    case case_c { $x = 1000 }
+    case case_c {
+        ok( !$self, "Cases are not methods" );
+        $x = 1000
+    }
 
     tests divisible_by_ten { ok( !($x % 10), "$x/10" )}
     tests positive { ok( $x, $x )}
 }
 
 describe a_describe {
+    ok( $self, "Magically got self" );
+    $self->isa_ok( 'TEST::Fennec::Declare' );
+    $self->isa_ok( 'Fennec::TestFile' );
+
     my $x = 0;
     before_each { $x = 10 };
     after_each { $x = 0 };
